@@ -1,17 +1,6 @@
-#define __GNOME_FONT_FACE_C__
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000-2001 Ximian Inc. and authors
- *
- *  Authors:
- *    Jody Goldberg <jody@ximian.com>
- *    Miguel de Icaza <miguel@ximian.com>
- *    Lauris Kaplinski <lauris@ximian.com>
- *    Christopher James Lahey <clahey@ximian.com>
- *    Michael Meeks <michael@ximian.com>
- *    Morten Welinder <terra@diku.dk>
- *
- *  GnomeFontFace - unscaled typeface
+ *  gnome-font-face.c: unscaled typeface
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public License
@@ -26,8 +15,21 @@
  *  You should have received a copy of the GNU Library General Public
  *  License along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors:
+ *    Jody Goldberg <jody@ximian.com>
+ *    Miguel de Icaza <miguel@ximian.com>
+ *    Lauris Kaplinski <lauris@ximian.com>
+ *    Christopher James Lahey <clahey@ximian.com>
+ *    Michael Meeks <michael@ximian.com>
+ *    Morten Welinder <terra@diku.dk>
+ *
+ *  Copyright (C) 2000-2001 Ximian Inc. and authors
+ *
  */
 
+#define __GNOME_FONT_FACE_C__
+
 #include <config.h>
 #include <stdlib.h>
 #include <ctype.h>
@@ -39,8 +41,8 @@
 #include <fcntl.h>
 #include <stdarg.h>
 #include <locale.h>
-#include <libgnomeprint/gnome-print-i18n.h>
 #include <libgnomeprint/gnome-font-private.h>
+#include "gnome-print-i18n.h"
 #include "gp-fontmap.h"
 #include "gp-truetype-utils.h"
 #include "gp-tt-t1.h"
@@ -860,17 +862,16 @@ typedef struct {
 static int gfft2_move_to (FT_Vector * to, void * user)
 {
 	GFFT2OutlineData * od;
-	ArtBpath * s;
 	ArtPoint p;
 
 	od = (GFFT2OutlineData *) user;
 
-	s = &od->bp[od->end - 1];
-
 	p.x = to->x * od->t[0] + to->y * od->t[2];
 	p.y = to->x * od->t[1] + to->y * od->t[3];
 
-	if ((p.x != s->x3) || (p.y != s->y3)) {
+	if (od->end == 0 ||
+	    p.x != od->bp[od->end - 1].x3 ||
+	    p.y != od->bp[od->end - 1].y3) {
 		od->bp[od->end].code = ART_MOVETO;
 		od->bp[od->end].x3 = to->x * od->t[0] + to->y * od->t[2];
 		od->bp[od->end].y3 = to->x * od->t[1] + to->y * od->t[3];
@@ -1097,19 +1098,17 @@ gff_pso_ensure_buffer_t1 (GFPSObject *pso)
 	}
 
 	/* Step 0: mmap pfb file */
-	if (stat (t1->pfb.name, &st)) {
-		g_warning ("file %s: line %d: Cannot stat font file %s", __FILE__, __LINE__, t1->pfb.name);
-		gff_pso_ensure_buffer_empty (pso);
-		return;
-	}
-
 	fh = open (t1->pfb.name, O_RDONLY);
 	if (fh < 0) {
 		g_warning ("file %s: line %d: Cannot open font file %s", __FILE__, __LINE__, t1->pfb.name);
 		gff_pso_ensure_buffer_empty (pso);
 		return;
 	}
-
+	if (fstat (fh, &st) != 0) {
+		g_warning ("file %s: line %d: Cannot fstat font file %s", __FILE__, __LINE__, t1->pfb.name);
+		gff_pso_ensure_buffer_empty (pso);
+		return;
+	}
 	fbuf = mmap (NULL, st.st_size, PROT_READ, MAP_SHARED, fh, 0);
 	close (fh);
 	if ((fbuf == NULL) || (fbuf == (guchar *) -1)) {
@@ -1118,6 +1117,7 @@ gff_pso_ensure_buffer_t1 (GFPSObject *pso)
 		return;
 	}
 
+	/* Step 1: */	   
 	if (*fbuf == 0x80) {
 		const char hextab[16] = "0123456789abcdef";
 		gint idx;
@@ -1166,6 +1166,7 @@ gff_pso_ensure_buffer_t1 (GFPSObject *pso)
 			}
 		}
 	} else {
+		gf_pso_ensure_space (pso, st.st_size);
 		memcpy (pso->buf, fbuf, st.st_size);
 		pso->buf[st.st_size] = '\0';
 		pso->length = st.st_size;
@@ -1185,9 +1186,9 @@ gff_pso_ensure_buffer_t1 (GFPSObject *pso)
 			gchar c[256];
 			FT_Error status;
 			g = (glyph < pso->face->num_glyphs) ? glyph : 0;
-			status = FT_Get_Glyph_Name (pso->face->ft_face, glyph, c, 256);
+			status = FT_Get_Glyph_Name (pso->face->ft_face, g, c, 256);
 			if (status != FT_Err_Ok) {
-				g_warning ("file %s: line %d: Glyph %d has no name in %s", __FILE__, __LINE__, glyph, t1->pfb.name);
+				g_warning ("file %s: line %d: Glyph %d has no name in %s", __FILE__, __LINE__, g, t1->pfb.name);
 #if 0
 				gff_pso_ensure_buffer_empty (pso);
 				return;
@@ -1195,6 +1196,9 @@ gff_pso_ensure_buffer_t1 (GFPSObject *pso)
 				g_snprintf (c, 256, ".notdef");
 #endif
 			}
+#ifdef __GNUC__
+#warning Should this be g or glyph? See bug #80415
+#endif
 			gf_pso_sprintf (pso, ((glyph & 0xf) == 0xf) ? "/%s\n" : "/%s ", c);
 		}
 		gf_pso_sprintf (pso, "] def currentdict end\n");
@@ -1277,19 +1281,17 @@ gff_pso_ensure_buffer_tt (GFPSObject *pso)
 	tt = (GPFontEntryTT *) pso->face->entry;
 
 	/* mmap file */
-	if (stat (tt->ttf.name, &st)) {
-		g_warning ("file %s: line %d: Face: %s: Cannot load face", __FILE__, __LINE__, pso->face->entry->name);
-		gff_pso_ensure_buffer_empty (pso);
-		return;
-	}
-
 	fh = open (tt->ttf.name, O_RDONLY);
 	if (fh < 0) {
 		g_warning ("file %s: line %d: Cannot open font file %s", __FILE__, __LINE__, tt->ttf.name);
 		gff_pso_ensure_buffer_empty (pso);
 		return;
 	}
-
+	if (fstat (fh, &st) != 0) {
+		g_warning ("file %s: line %d: Face: %s: Cannot fstat face", __FILE__, __LINE__, tt->ttf.name);
+		gff_pso_ensure_buffer_empty (pso);
+		return;
+	}
 	fbuf = mmap (NULL, st.st_size, PROT_READ, MAP_SHARED, fh, 0);
 	close (fh);
 	if ((fbuf == NULL) || (fbuf == (guchar *) -1)) {
@@ -1566,13 +1568,21 @@ gff_pso_from_type1 (const GnomeFontFace *face, GPFontEntry *entry)
 	t1 = (GPFontEntryT1 *) entry;
 
 	/* mmap file */
-	if (stat (t1->pfb.name, &st) != 0) return gff_empty_pso (face, entry);
 	fh = open (t1->pfb.name, O_RDONLY);
-	if (fh < 0) return gff_empty_pso (face, entry);
+	if (fh < 0) {
+		g_warning ("file %s: line %d: Cannot open file %s", __FILE__, __LINE__, t1->pfb.name);
+		return gff_empty_pso (face, entry);
+	}
+	if (fstat (fh, &st) != 0) {
+		g_warning ("file %s: line %d: Cannot fstat file %s", __FILE__, __LINE__, t1->pfb.name);
+		return gff_empty_pso (face, entry);
+	}
 	fbuf = mmap (NULL, st.st_size, PROT_READ, MAP_SHARED, fh, 0);
 	close (fh);
-	if (fbuf == NULL) return gff_empty_pso (face, entry);
-	if (fbuf == (guchar *) -1) return gff_empty_pso (face, entry);
+	if ((fbuf == NULL) || (fbuf == (guchar *) -1)) {
+		g_warning ("file %s: line %d: Cannot mmap file %s", __FILE__, __LINE__, t1->pfb.name);
+		return gff_empty_pso (face, entry);
+	}
 
 	pso = g_new (GFPSObject, 1);
 	pso->bufsize = st.st_size + 1024;
@@ -1746,13 +1756,21 @@ gff_pso_from_truetype (const GnomeFontFace *face, GPFontEntry *entry)
 	tt = (GPFontEntryTT *) entry;
 
 	/* mmap file */
-	if (stat (tt->ttf.name, &st) != 0) return gff_empty_pso (face, entry);
 	fh = open (tt->ttf.name, O_RDONLY);
-	if (fh < 0) return gff_empty_pso (face, entry);
+	if (fh < 0) {
+		g_warning ("file %s: line %d: Cannot open file %s", __FILE__, __LINE__, filename);
+		return gff_empty_pso (face, entry);
+	}
+	if (fstat (fh, &st) != 0) {
+		g_warning ("file %s: line %d: Cannot fstat file %s", __FILE__, __LINE__, filename);
+		return gff_empty_pso (face, entry);
+	}
 	fbuf = mmap (NULL, st.st_size, PROT_READ, MAP_SHARED, fh, 0);
 	close (fh);
-	if (fbuf == NULL) return gff_empty_pso (face, entry);
-	if (fbuf == (guchar *) -1) return gff_empty_pso (face, entry);
+	if ((fbuf == NULL) || (fbuf == (guchar *) -1)) {
+		g_warning ("file %s: line %d: Cannot mmap file %s", __FILE__, __LINE__, filename);
+		return gff_empty_pso (face, entry);
+	}
 
 	strings = gp_tt_split_file (fbuf, st.st_size);
 	if (strings == NULL) {
