@@ -1,32 +1,33 @@
-#define __GNOME_PRINT_PS2_C__
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gnome-print-ps2.c: A Postscript driver for GnomePrint based on
- * gnome-print-pdf which was based on the PS driver by Raph Levien.
+ *  gnome-print-ps2.c: A Postscript driver for GnomePrint
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public License
+ *  as published by the Free Software Foundation; either version 2 of
+ *  the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * Authors:
- *   Chema Celorio <chema@celorio.com>
- *   Lauris Kaplinski <lauris@helixcode.com>
+ *  Authors:
+ *    Chema Celorio <chema@celorio.com>
+ *    Lauris Kaplinski <lauris@helixcode.com>
  *
- * Copyright 2000-2001 Ximian, Inc. and authors
+ *  Copyright 2000-2001 Ximian, Inc. and authors
  *
  */
 
+#define __GNOME_PRINT_PS2_C__
+
+#include <config.h>
+
 #include <math.h>
 #include <string.h>
 #include <time.h>
