@@ -1,12 +1,6 @@
-#define __GNOME_RFONT_C__
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000-2001 Ximian Inc. and authors
- *
- *  Authors:
- *    Lauris Kaplinski <lauris@ximian.com>
- *
- *  GnomeFontFace - grid fitted font
+ *  gnome-rfont.c: grid fitted font
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public License
@@ -21,8 +15,16 @@
  *  You should have received a copy of the GNU Library General Public
  *  License along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors:
+ *    Lauris Kaplinski <lauris@ximian.com>
+ *
+ *  Copyright (C) 2000-2001 Ximian Inc. and authors
+ *
  */
 
+#define __GNOME_RFONT_C__
+
 #include <math.h>
 #include <string.h>
 #include <ctype.h>
@@ -680,9 +682,13 @@ gnome_rfont_get_glyph_svp (GnomeRFont * rfont, gint glyph)
 
 	if (svp) return svp;
 
+#ifdef __GNUC__	
+#warning FIXME
+#endif
 	/* fixme: */
-
+#if 0	
 	g_print ("New SVP for %d\n", glyph);
+#endif	
 
 	bpath = (ArtBpath *) gnome_rfont_get_glyph_bpath (rfont, glyph);
 
