@@ -1,20 +1,35 @@
-#define _GP_FONTMAP_C_
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Fontmap implementation
+ *  gp-fontmap.c: fontmap implementation
  *
- * Authors:
- *   Lauris Kaplinski <lauris@ximian.com>
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public License
+ *  as published by the Free Software Foundation; either version 2 of
+ *  the License, or (at your option) any later version.
  *
- * Copyright (C) 2000-2001 Ximian, Inc.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
  *
- * TODO: Recycle font entries, if they are identical for different maps
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors:
+ *    Lauris Kaplinski <lauris@ximian.com>
+ *
+ *  Copyright (C) 2000-2001 Ximian, Inc.
  *
  */
 
+#define _GP_FONTMAP_C_
+
+/* TODO: Recycle font entries, if they are identical for different maps */
+
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/time.h>
+#include <time.h>
 #include <stdlib.h>
 #include <string.h>
 #include <dirent.h>
