@@ -1,30 +1,30 @@
-#define __GPA_CONFIG_C__
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * This file is part of libgnomeprint 2
+ *  gpa-config.c: 
  *
- * Libgnomeprint is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public License
+ *  as published by the Free Software Foundation; either version 2 of
+ *  the License, or (at your option) any later version.
  *
- * Libgnomeprint is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with the libgnomeprint; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * Authors :
- *   Lauris Kaplinski <lauris@ximian.com>
+ *  Authors :
+ *    Lauris Kaplinski <lauris@ximian.com>
  *
- * Copyright (C) 2001 Ximian, Inc.
+ *  Copyright (C) 2000-2001 Ximian, Inc.
  *
  */
 
+#define __GPA_CONFIG_C__
+
 #include <string.h>
 #include "gpa-utils.h"
 #include "gpa-reference.h"
@@ -40,6 +40,7 @@ static void gpa_config_init (GPAConfig *config);
 
 static void gpa_config_finalize (GObject *object);
 
+static GPANode *gpa_config_duplicate (GPANode *node);
 static gboolean gpa_config_verify (GPANode *node);
 static guchar *gpa_config_get_value (GPANode *node);
 static GPANode *gpa_config_get_child (GPANode *node, GPANode *ref);
@@ -84,6 +85,7 @@ gpa_config_class_init (GPAConfigClass *klass)
 
 	object_class->finalize = gpa_config_finalize;
 
+	node_class->duplicate = gpa_config_duplicate;
 	node_class->verify = gpa_config_verify;
 	node_class->get_value = gpa_config_get_value;
 	node_class->get_child = gpa_config_get_child;
@@ -272,3 +274,26 @@ gpa_config_printer_set_value (GPAReference *reference, const guchar *value, gpoi
 
 	return FALSE;
 }
+
+static GPANode *
+gpa_config_duplicate (GPANode *node)
+{
+	GPAConfig *config, *new;
+
+	config = GPA_CONFIG (node);
+
+	new = (GPAConfig *) gpa_node_new (GPA_TYPE_CONFIG, GPA_NODE_ID (node));
+
+	if (config->globals)
+		new->globals = gpa_node_attach (GPA_NODE (new), 
+						gpa_node_duplicate (config->globals));
+	if (config->printer)
+		new->printer = gpa_node_attach (GPA_NODE (new), 
+						gpa_node_duplicate (config->printer));
+	if (config->settings)
+		new->settings = gpa_node_attach (GPA_NODE (new), 
+						 gpa_node_duplicate (config->settings));
+
+	return GPA_NODE (new);
+}
+
