@@ -1,30 +1,31 @@
-#define __GPA_LIST_C__
-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * This file is part of libgnomeprint 2
+ *  gpa-list.c: 
  *
- * Libgnomeprint is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public License
+ *  as published by the Free Software Foundation; either version 2 of
+ *  the License, or (at your option) any later version.
  *
- * Libgnomeprint is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with the libgnomeprint; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * Authors :
- *   Lauris Kaplinski <lauris@ximian.com>
+ *  Authors :
+ *    Jose M. Celorio <chema@ximian.com>
+ *    Lauris Kaplinski <lauris@ximian.com>
  *
- * Copyright (C) 2001 Ximian, Inc.
+ *  Copyright (C) 2000-2001 Ximian, Inc. and Jose M. Celorio
  *
  */
 
+#define __GPA_LIST_C__
+
 #include <string.h>
 #include "gpa-utils.h"
 #include "gpa-reference.h"
@@ -100,7 +101,6 @@ gpa_list_finalize (GObject *object)
 
 	if (list->def) {
 		list->def = gpa_node_detach_unref (GPA_NODE (list), GPA_NODE (list->def));
-		list->def = NULL;
 	}
 
 	while (list->children) {
@@ -187,7 +187,7 @@ gpa_list_construct (GPAList *gpl, GType childtype, gboolean has_def)
 	gpl->childtype = childtype;
 	gpl->has_def = has_def;
 	if (has_def) {
-		gpl->def = gpa_reference_new_empty ();
+		gpl->def = gpa_node_attach (GPA_NODE (gpl), gpa_reference_new_empty ());
 		g_signal_connect (G_OBJECT (gpl->def), "set_value",
 				  (GCallback) gpa_list_def_set_value, gpl);
 	}
