@@ -32,7 +32,6 @@ G_BEGIN_DECLS
 
 #include <glib-object.h>
 #include "gpa-utils.h"
-#include "../gpa-private.h"
 
 #define GPA_NODE_MODIFIED_SHIFT 0
 #define GPA_NODE_MODIFIED_FLAG (1 << GPA_NODE_MODIFIED_SHIFT)
@@ -87,6 +86,10 @@ GPANode *gpa_node_lookup (GPANode *node, const guchar *path);
 void gpa_node_request_modified (GPANode *node, guint flags);
 void gpa_node_emit_modified (GPANode *node, guint flags);
 
+
+/* fixme: */
+GSList *gpa_list_nodes (void);
+
 G_END_DECLS
 
 #endif
