@@ -71,11 +71,6 @@ xmlNodePtr gpa_settings_write (xmlDocPtr doc, GPANode *settings);
 gboolean gpa_settings_copy (GPASettings *dst, GPASettings *src);
 
 #if 0
-GPANode *gpa_settings_new (void);
-
-#define gpa_settings_ref(p)   gpa_node_ref (p)
-#define gpa_settings_unref(p) gpa_node_ref (p)
-
 /* GPASettingsList */
 
 GPANode *gpa_settings_list_new (void);
