@@ -52,6 +52,7 @@ GPANode *gpa_node_detach_unref_next (GPANode *parent, GPANode *child);
 
 /* Lookup */
 
+const guchar *gpa_node_lookup_check (const guchar *path, const guchar *key);
 gboolean gpa_node_lookup_ref (GPANode **child, GPANode *node, const guchar *path, const guchar *key);
 
 /* XML helpers */
@@ -59,6 +60,10 @@ gboolean gpa_node_lookup_ref (GPANode **child, GPANode *node, const guchar *path
 xmlChar *gpa_xml_node_get_name (xmlNodePtr node);
 xmlNodePtr gpa_xml_node_get_child (xmlNodePtr node, const guchar *name);
 
+/* Cache */
+
+GPANode *gpa_node_cache (GPANode *node);
+
 /* Private quarks */
 
 typedef guint GPAQuark;
@@ -68,39 +73,6 @@ GPAQuark gpa_quark_from_string (const guchar *string);
 GPAQuark gpa_quark_from_static_string (const guchar *string);
 const guchar *gpa_quark_to_string (GPAQuark quark);
 
-#if 0
-#include <gpa-private.h>
-#include <gpa-known.h>
-#include <time.h>   /* For time() */
-
-extern gboolean   debug_turned_on;
-
-/* Hash handling */
-GHashTable* gpa_hash_copy (GHashTable *values);
-gboolean    gpa_hash_free (GHashTable *values);
-xmlNodePtr  gpa_hash_write (XmlParseContext *context,
-					   GHashTable *values,
-					   const gchar *name);
-gboolean      gpa_hash_item_set (GHashTable *hash,
-						   const gchar *key,
-						   const gchar *content);
-const gchar * gpa_hash_item_get (GHashTable *hash,
-						   const gchar *key);
-
-
-gboolean gpa_hash_verify (GHashTable *hash,
-					 const GpaKnownNodes *nodes,
-					 gboolean xtra_flag,
-					 const gchar *section);
-
-gchar * gpa_utils_convert_date_to_string (time_t clock);
-
-/*
-gboolean
-gp_hash_verify (GHashTable *hash, const GpaKnownNodes nodes, gboolean xtra_flag);
-*/
-#endif
-
 G_END_DECLS
 
 #endif /* __GPA_UTILS_H__ */
