@@ -26,6 +26,7 @@
  *
  */
 
+#include <config.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -35,13 +36,14 @@
 #include <popt.h>
 #include <math.h>
 #include <libbonobo.h>
-#include <libgnomeprint/gnome-print-i18n.h>
+#include <libgnomeprint/gnome-print-meta.h>
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-master.h>
 #include <libgnomeprint/gnome-print-paper.h>
 #include <libgnomeprint/gnome-print-meta.h>
 #include <libgnomeprint/gnome-print-bonobo.h>
 #include <libgnomeprint/gnome-print-bonobo-client.h>
+#include "../libgnomeprint/gnome-print-i18n.h"
 
 #define WE_ARE_LIBGNOMEPRINT_UI
 #include <libgnomeprint/gpa-private.h>
@@ -54,24 +56,20 @@
 
 static gchar *textfile = NULL;
 static gchar *dumpfile = NULL;
+static gchar *metafile = NULL;
 static gboolean master = FALSE;
 static gboolean bonobo = FALSE;
 static gboolean papers = FALSE;
 static gboolean gpa = FALSE;
 
 static struct poptOption options[] = {
-	{ "papers", 'p', POPT_ARG_NONE, &papers, 0,
-	  N_("Print Paper database"), NULL},
-	{ "gpa", 'g', POPT_ARG_NONE, &gpa, 0,
-	  N_("Describe GPA Tree"), NULL},
-	{ "text", 't', POPT_ARG_STRING, &textfile, 0,
-	  N_("Print text file"), N_("PATH")},
-	{ "master", 'm', POPT_ARG_NONE, &master, 0,
-	  N_("Use GnomePrintMaster for printing"), NULL},
-	{ "dump", 'd', POPT_ARG_STRING, &dumpfile, 0,
-	  N_("Dump printout to metafile ('-' for stdout)"), N_("PATH")},
-	{ "bonobo", 'b', POPT_ARG_NONE, &bonobo, 0,
-	  N_("Split job between bonobo"), NULL},
+	{ "papers",   'p', POPT_ARG_NONE,   &papers,   0, N_("Print Paper database"), NULL},
+	{ "gpa",      'g', POPT_ARG_NONE,   &gpa,      0, N_("Describe GPA Tree"), NULL},
+	{ "text",     't', POPT_ARG_STRING, &textfile, 0, N_("Print text file"), N_("PATH")},
+	{ "master",   'm', POPT_ARG_NONE,   &master,   0, N_("Use GnomePrintMaster for printing"), NULL},
+	{ "dump",     'd', POPT_ARG_STRING, &dumpfile, 0, N_("Dump printout to metafile ('-' for stdout)"), N_("PATH")},
+	{ "bonobo",   'b', POPT_ARG_NONE,   &bonobo,   0, N_("Split job between bonobo"), NULL},
+	{ "metafile", 'm', POPT_ARG_STRING, &metafile, 0, N_("Render from metafile"), N_("PATH")},
 	POPT_AUTOHELP
 	{ NULL, '\0', 0, NULL, 0 }
 };
@@ -143,7 +141,9 @@ print_page (GnomePrintContext *pc)
 	gl = gnome_glyphlist_from_text_dumb (font, 0x000000ff, 0.0, 0.0, _("Gnome-print test page, rotated"));
 	gnome_glyphlist_bbox (gl, NULL, 0, &bbox);
 	gnome_print_setrgbcolor (pc, 0.9, 0.8, 0.6);
+#if 0
 	g_print ("bbox: %g %g %g %g\n", bbox.x0, bbox.y0, bbox.x1, bbox.y1);
+#endif	
 	gnome_print_rect_filled (pc, bbox.x0 - 2.0, bbox.y0 - 2.0, bbox.x1 + 2.0 - bbox.x0, bbox.y1 + 2.0 - bbox.y0);
 	gnome_print_moveto (pc, 0.0, 0.0);
 	gnome_print_glyphlist (pc, gl);
@@ -474,7 +474,11 @@ main (int argc, const char **argv)
 				}
 			}
 		} else {
-			print_test_page (pctx);
+			if (metafile) {
+				gnome_print_meta_render_file (pctx, metafile);
+			} else {
+				print_test_page (pctx);
+			}
 		}
 	}
 
